Gpapi

Struct Gpapi 

pub struct Gpapi { /* private fields */ }

Implementations

Source

impl Gpapi

pub fn new<S: Into<String>>(device: Device, email: S) -> Self

Returns a Gpapi struct.

pub fn set_locale<S: Into<String>>(&mut self, locale: S)

Set the locale

pub fn set_timezone<S: Into<String>>(&mut self, timezone: S)

Set the time zone

pub fn set_aas_token<S: Into<String>>(&mut self, aas_token: S)

Set the aas token. This can be requested via request_aas_token, and is required for most other actions.

pub async fn request_aas_token<S: Into<String>>( &mut self, oauth_token: S, ) -> Result<(), GpapiError>

Request and set the aas token given an oauth token and the associated email.

Arguments
  • oauth_token - An oauth token you previously retrieved separately
pub fn get_aas_token(&self) -> Option<&str>

Get the aas token that has been previously set by either request_aas_token or set_aas_token.

pub async fn login(&mut self) -> Result<(), GpapiError>

Log in to Google’s Play Store API. This is required for most other actions. The aas token has to be set via request_aas_token or set_aas_token first.

pub async fn get_download_info<S>( &self, package: S, version_code: Option<i32>, ) -> Result<DownloadInfo, GpapiError>
where S: Into<String>,

Retrieve files with download URLs for a package.

Arguments
  • package - Package ID, such as moe.low.arc.
  • version_code - Optional version code, if None, the latest version will be used.
Returns

If successful, Ok with the files to download for the package.

pub async fn details<S: Into<String>>( &self, pkg_name: S, ) -> Result<Option<DetailsResponse>, Box<dyn Error>>

Play Store package detail request (provides more detail than bulk requests).

Arguments
  • pkg_name - A string type specifying the package’s app ID, e.g. com.instagram.android
pub async fn bulk_details( &self, pkg_names: &[&str], ) -> Result<Option<BulkDetailsResponse>, GpapiError>

Play Store bulk detail request for multiple apps.

Arguments
  • pkg_names - An array of string types specifying package app IDs
pub async fn accept_tos( &mut self, ) -> Result<Option<AcceptTosResponse>, Box<dyn Error>>

Accept the play store terms of service.