pub struct Gpapi { /* private fields */ }Implementations
Sourceimpl Gpapi
impl Gpapi
Sourcepub fn set_locale<S: Into<String>>(&mut self, locale: S)
pub fn set_locale<S: Into<String>>(&mut self, locale: S)
Set the locale
Sourcepub fn set_timezone<S: Into<String>>(&mut self, timezone: S)
pub fn set_timezone<S: Into<String>>(&mut self, timezone: S)
Set the time zone
Sourcepub fn set_aas_token<S: Into<String>>(&mut self, aas_token: S)
pub fn set_aas_token<S: Into<String>>(&mut self, aas_token: S)
Set the aas token. This can be requested via request_aas_token, and is required for most
other actions.
Sourcepub async fn request_aas_token<S: Into<String>>(
&mut self,
oauth_token: S,
) -> Result<(), GpapiError>
pub async fn request_aas_token<S: Into<String>>( &mut self, oauth_token: S, ) -> Result<(), GpapiError>
Request and set the aas token given an oauth token and the associated email.
Arguments
oauth_token- An oauth token you previously retrieved separately
Sourcepub fn get_aas_token(&self) -> Option<&str>
pub fn get_aas_token(&self) -> Option<&str>
Get the aas token that has been previously set by either request_aas_token or
set_aas_token.
Sourcepub async fn login(&mut self) -> Result<(), GpapiError>
pub async fn login(&mut self) -> Result<(), GpapiError>
Log in to Google’s Play Store API. This is required for most other actions. The aas token
has to be set via request_aas_token or set_aas_token first.
Sourcepub async fn get_download_info<S>(
&self,
package: S,
version_code: Option<i32>,
) -> Result<DownloadInfo, GpapiError>
pub async fn get_download_info<S>( &self, package: S, version_code: Option<i32>, ) -> Result<DownloadInfo, GpapiError>
Sourcepub async fn details<S: Into<String>>(
&self,
pkg_name: S,
) -> Result<Option<DetailsResponse>, Box<dyn Error>>
pub async fn details<S: Into<String>>( &self, pkg_name: S, ) -> Result<Option<DetailsResponse>, Box<dyn Error>>
Play Store package detail request (provides more detail than bulk requests).
Arguments
pkg_name- A string type specifying the package’s app ID, e.g.com.instagram.android
Sourcepub async fn bulk_details(
&self,
pkg_names: &[&str],
) -> Result<Option<BulkDetailsResponse>, GpapiError>
pub async fn bulk_details( &self, pkg_names: &[&str], ) -> Result<Option<BulkDetailsResponse>, GpapiError>
Play Store bulk detail request for multiple apps.
Arguments
pkg_names- An array of string types specifying package app IDs
Sourcepub async fn accept_tos(
&mut self,
) -> Result<Option<AcceptTosResponse>, Box<dyn Error>>
pub async fn accept_tos( &mut self, ) -> Result<Option<AcceptTosResponse>, Box<dyn Error>>
Accept the play store terms of service.